@@ -839,7 +839,7 @@ static void setup_frame_window(
 	/* This adds preliminary support for ARGB windows in fvwm. It should
 	   evolve to proper ARGB support in frames, menus and modules */
 	format=FRenderFindVisualFormat(dpy, fw->attr_backup.visual);
-	if (format != NULL && format->type==PictTypeDirect &&
+	if (format != NULL && format->type == FRenderPictTypeDirect &&
 		format->direct.alphaMask > 0)
 	{
 		depth = fw->attr_backup.depth;
@@ -2125,8 +2125,8 @@ Bool setup_transientfor(FvwmWindow *fw)
  *
  */
 FvwmWindow *AddWindow(
-	const exec_context_t *exc, FvwmWindow *ReuseWin,
-	initial_window_options_t * win_opts)
+	const char **ret_initial_map_command, const exec_context_t *exc,
+	FvwmWindow *ReuseWin, initial_window_options_t * win_opts)
 {
 	/* new fvwm window structure */
 	register FvwmWindow *fw;
@@ -2242,6 +2242,11 @@ FvwmWindow *AddWindow(
 			fw->class.res_class);
 	}
 
+	/****** InitialMapCommand ******/
+	*ret_initial_map_command =
+		(style.flags.has_initial_map_command_string) ?
+		SGET_INITIAL_MAP_COMMAND_STRING(style) : NULL;
+
 	/****** state setup ******/
 	setup_icon_boxes(fw, &style);
 	SET_ICONIFIED(fw, 0);
